#!/bin/bash

#   functions.sh - a bunch of functions used in the other scripts
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.


# simple input thing
# USAGE:
# getInpute "Enter the info we need please : " type
# type = user | pw | domain | dir
# var1="${ANSWER}"
getInpute () {
	COUNTER=0
	if [ "${2}" = "user" ]; then REGEX="^([0-9a-z\-]{3,16})$"; fi
	if [ "${2}" = "pw" ]; then REGEX="^.{6,}$"; fi
	if [ "${2}" = "dir" ]; then REGEX="^[/a-zA-Z0-9_\.\-]+$"; fi
	if [ "${2}" = "domain" ]; then REGEX="^[a-z0-9\.\-]+$"; fi
	if [ "${2}" = "db" ]; then REGEX="^[a-zA-Z0-9_\.\-]+$"; fi
	echo -n "${1} "
	while read ANSWER; do
		if [[ "${ANSWER}" =~ ${REGEX} ]] && [ -n "${ANSWER}" ]; then
			break
		fi
		if [ "${COUNTER}" = "0" ]; then
			echo "Answer contains forbidden characters,
you must use:"
			if [ "${2}" = "user" ]; then
				echo "
- lower case letters
- numbers (0-9)
- between 3 and 16 characters"
			elif [ "${2}" = "pw" ]; then
				echo "
- at least 6 characters"
			elif [ "${2}" = "dir" ]; then
				echo "
- lower/upper case letters
- numbers
- \". _ - /\""
			elif [ "${2}" = "domain" ]; then
				echo "
- lower case letters
- numbers
- \". -\""
			elif [ "${2}" = "db" ]; then
				echo "
- lower/upper case letters
- numbers
- \". _ -\""
			fi
			echo -n "
${1} "
			COUNTER="`expr $COUNTER + 1`"
		else
			echo " Bad answer please try again"
			echo -n "${1} "
		fi
	done
}

# test if domain is already used by DISS
# USAGE:
# testDomain $1
testDomain () {
	for NDD in ${ALLDOMAINS[@]}; do
		if [ "${1}" = "${NDD}" ]; then
		echo "!!!   Error: \"${1}\" exists in DISS - exiting   !!!
 Press enter to proceed"
		read
		exit
		fi
	done

	SUBNDD=`echo ${1}|cut -d "." -f 1`
	for SDD in ${BLOCKSUBDOMAINS}; do
		if [ "${SUBNDD}" = "${SDD}" ]; then
		echo "!!!   Error: sub domain \"${SUBNDD}\" reserved in DISS config - exiting   !!!
 Press enter to proceed"
		read
		exit
		fi
	done
}

confirmORdie () {
	counter=0
	while [ $counter != 2 ]; do
	echo -n "Should we continue ? (y/N): "
	read GO
		if [ -n "${GO}" ];
		then
		break
		fi
	counter="`expr $counter + 1`"
	done
	if [ "${GO}" = "y" ] || [ "${GO}" = "Y" ]; then
		echo "Continuing..."
		else
		echo "Exiting... (press enter to proceed)"
		read
		exit
	fi
}


# test dependancy
# get these values:
# DEPENDSTATE=${WEBSTATE}
# DEPENDSON="install_lamp"
dependsOn () {
	if [ "${DEPENDSTATE}" != "done" ]; then
        	${WHIPMSG} "this step depends on \"${DEPENDSON}\".

Please execute the script \"${DEPENDSON}\" before
executing \"${THISSCRIPT}\" ." 0 0
		exit
	fi
}

# test if the this part has been installed.
# get these values:
# THISSCRIPT=install_lamp.sh
# THISSTATE=${WEBSTATE}
installStatus () {
	if [ "${THISSTATE}" == "done" ]; then
		${WHIPMSG} "this step has already been done.
if you need to fix something then you
can consult the \"${THISSCRIPT}\" script
located in \"/usr/local/diss/scripts/\"" 0 0
		exit
	fi
}

# value to get
# TESTINTEGER=${VAR}
testInteger () {
	if [ "${TESTINTEGER}" -eq "${TESTINTEGER}" > /dev/null 2>&1 ] ; then
		true
	else
		echo "Bad input, please try again"
		read
		exit
fi
}

# pick a client
pickAclient () {
	for ACCOUNTS in `ls /etc/diss/clients/|cut -d '.' -f 1`;
		do
		ACCOUNT=( "${ACCOUNT[@]}" "${ACCOUNTS}" )
	done
	height=`expr ${#ACCOUNT[@]} - 1`
	for i in $(seq 0 $height); do
		if [ -n "${ACCOUNT[$i]}" ]; then
		echo "$i. ${ACCOUNT[$i]}"
		fi
	done
	echo "Q. Press \"q\" to return to main menu"
	echo -n "Pick a client from the list: "
	while read NO; do
		if [ "${NO}" = "q" ] || [ "${NO}" = "Q" ]; then
			exit
		elif [ "${NO}" -eq "${NO}" > /dev/null 2>&1 ] && [ -n "${NO}" ] && (("${NO}" >= "0")) && (("${NO}" <= "$height")); then
			source /etc/diss/clients/${ACCOUNT[$NO]}.conf
			break
		fi
			echo "Bad input, please try again"
			echo -n "Pick a client from the list: "
	done
}

# pick a domain from client
pickAdomain () {
	echo "
Listing ${ACCOUNT[$NO]}'s domains : "
	for i in `cat /etc/diss/clients/${ACCOUNT[$NO]}.conf |grep CLIENTDOMAIN|cut -d "[" -f 2|cut -d "]" -f 1`;
		do  echo "$i. ${CLIENTDOMAIN[$i]}";
		VALIDNO="$i ${VALIDNO}"
	done
	echo "Q. Quit"
	echo -n "Pick a domain ? "
	while read NDDNO; do
		for BAD in ${VALIDNO}; do
			if [ "${NDDNO}" -ne "${BAD}" ]; then
				GOOD=0
			else
				GOOD=1
				break
		fi
		done
		if [ "${NDDNO}" = "q" ] || [ "${NDDNO}" = "Q" ]; then
			exit
		elif [ "${NDDNO}" -eq "${NDDNO}" > /dev/null 2>&1 ] && [ -n "${NDDNO}" ] && [ "$GOOD" = "1" ]; then
			echo "You picked: ${CLIENTDOMAIN[NDDNO]}"
			break
		fi
		echo "Bad input, please try again"
		echo -n "Pick a domain ? "
	done
}

# pick a database
pickAdb () {
	echo "
Listing ${ACCOUNT[$NO]}'s databases : "
	ALLDB=`mysql -uroot -p${ROOTSQL} -ss -e "show databases LIKE '${ACCOUNT[$NO]}_%';"|sort`
	COUNTER=1
	for i in ${ALLDB}; do
		DB[$COUNTER]=$i
		COUNTER=`expr $COUNTER + 1`
	done
	height=${#DB[@]}
	for i in $(seq 1 $height); do
		if [ -n "${DB[$i]}" ]; then
			echo "$i. ${DB[$i]}"
		fi
	done
	echo "Q. Quit"
	echo -n "pick one: "
	while read DBNO; do
		if [ "${DBNO}" = "q" ] || [ "${DBNO}" = "q" ]; then
			exit
		fi
		if [ -n "${DBNO}" ] && [ "${DBNO}" -eq "${DBNO}" > /dev/null 2>&1 ] && (("${DBNO}" >= "1")) && (("${DBNO}" <= $height)); then
			echo "You picked: ${DB[$DBNO]}"
			break
		fi
		echo "Bad input, please try again"
		echo -n "pick one: "
	done
}

mkBackupDir () {
	if [ ! -d "${CLIENTPATH}/backup/" ]; then
		mkdir ${CLIENTPATH}/backup/
		chown ${CLIENT}:${CLIENT} ${CLIENTPATH}/backup/
		chmod 700 ${CLIENTPATH}/backup/
	fi
}

# backup a website
# Usage: backupAsite domain.tld
backupAsite () {
	mkBackupDir
	RMDOMAIN=`echo ${CLIENTDOMAIN[NDDNO]}|awk '{print $1}'`
	cd ${CLIENTPATH}/
	tar zcvf ${CLIENTPATH}/backup/${RMDOMAIN}_${DATE}.tar.gz ${RMDOMAIN}
	echo "Website ${RMDOMAIN} backed up in ${CLIENTPATH}/backup/${RMDOMAIN}_${DATE}.tar.gz"
}

# backup a DB
# Usage: backupAdb db_name dest (if no dest then user/backup/file.sql)
backupAdb () {
	mkBackupDir
	mysqldump --databases ${1} -p${ROOTSQL} > ${CLIENTPATH}/backup/${1}_${DATE}.sql
	echo "Database ${1} is backed up in ${CLIENTPATH}/backup/${1}_${DATE}.sql"
}

generateStatlinks () {
	CLIENTTMP="${CLIENT}"
	if [ -a "${ADMINNIMDAPATH}/clients.php" ]; then mv ${ADMINNIMDAPATH}/clients.php ${ADMINNIMDAPATH}/clients.php.bkp; fi
	for CLIENTSSTATS in `find /etc/diss/clients/* -type f`; do
		source ${CLIENTSSTATS}
		if [ ${CLIENTSSTATS} != /etc/diss/clients/${ADMINUSER}.conf ]; then
        		echo "<h3>Statistics for <strong>${CLIENT}</strong></h3>
<ul>
<? include(\"${CLIENTNIMDAPATH}/links.html\"); ?>
</ul>
" >> ${ADMINNIMDAPATH}/clients.php
		fi
	done
	CLIENT="${CLIENTTMP}"
	source /etc/diss/clients/${CLIENT}.conf
        if [ -a "${ADMINNIMDAPATH}/clients.php.bkp" ]; then rm ${ADMINNIMDAPATH}/clients.php.bkp; fi
}
